@@ -76,7 +76,7 @@ class GlobalChemExtensions(object):
 
         '''
 
-        PCAAnalysis(
+        pca_analysis = PCAAnalysis(
             smiles_list,
             morgan_radius,
             bit_representation,
@@ -87,4 +87,9 @@ class GlobalChemExtensions(object):
             save_file=save_file
         )
 
+        pca_analysis.conduct_analysis()
+
+
+
+
 
