@@ -134,9 +134,9 @@ class PCAAnalysis(object):
         plot = figure(plot_width=1000, plot_height=1000, tooltips=TOOLTIPS, title='Compounds')
         plot.circle('x', 'y',color='fill_color', size=10, fill_alpha=0.2,source=source)
 
-        plot = gridplot([
-            [plot]
-        ])
+        # plot = gridplot([
+        #     [plot]
+        # ])
 
 
         if self.save_file:
@@ -146,6 +146,6 @@ class PCAAnalysis(object):
 
         else:
 
-            show(plot)
+            # show(plot)
             plot
 
